@@ -131,6 +131,7 @@ if(isset($_GET['action'])) {
                 else if($rs[imei_mode]==0) $imei_ck1='selected';
                 else if($rs[imei_mode]==2) $imei_ck3='selected';
                 else if($rs[imei_mode]==3) $imei_ck4='selected';
+                else if($rs[imei_mode]==4) $imei_ck5='selected';
                 
                 if($rs[no_ring_disable]) $wa_ck1='checked';
                 if($rs[no_answer_disable]) $wa_ck2='checked';
@@ -192,6 +193,7 @@ if(isset($_GET['action'])) {
 		//echo DEV_BINDING;
 		if(!$team_id){
 			$send[]=my_pack2(DEV_BINDING, $sim_name, $_POST[line_name]);
+			echo "1111111";
 		}
 		else {
 			$send[]=my_pack2(DEV_BINDING, $sim_name, 0);
@@ -440,7 +442,9 @@ if(isset($_GET['action'])) {
 			
 			if($row['imei_mode']==1) $row['imei_type_name']="Random";
 			else if($row['imei_mode']==0) $row['imei_type_name']="GoIP default";
-			else if($row['imei_mode']==2) $row['imei_type_name']="Set with SIM";
+			else if($row['imei_mode']==2) $row['imei_type_name']="Set with SIM Slot";
+			else if($row['imei_mode']==3) $row['imei_type_name']="Random with IMSI";
+			else if($row['imei_mode']==4) $row['imei_type_name']="Database with IMSI";
 			$row['remain_limit']="total remain time: ".$row['remain_time']."/".$row['time_limit']."\n";
                         $row['remain_limit'].="total remain count: ".$row['count_remain']."/".$row['count_limit']."\n";
                         $row['remain_limit'].="total remain no connected count: ".$row['no_connected_remain']."/".$row['no_connected_limit']."\n";
